@@ -2,15 +2,24 @@
 ## School of Computer Science & Software Engineering
 ## The University of Western Australia
 ## http://www.csse.uwa.edu.au/
-##   
+##
 ## Permission is hereby granted, free of charge, to any person obtaining a copy
 ## of this software and associated documentation files (the "Software"), to deal
-## in the Software without restriction, subject to the following conditions:
-## 
-## The above copyright notice and this permission notice shall be included in all
-## copies or substantial portions of the Software.
-## 
-## The Software is provided "as is", without warranty of any kind.
+## in the Software without restriction, including without limitation the rights
+## to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+## copies of the Software, and to permit persons to whom the Software is
+## furnished to do so, subject to the following conditions:
+##
+## The above copyright notice and this permission notice shall be included in
+## all copies or substantial portions of the Software.
+##
+## The software is provided "as is", without warranty of any kind, express or
+## implied, including but not limited to the warranties of merchantability,
+## fitness for a particular purpose and noninfringement. In no event shall the
+## authors or copyright holders be liable for any claim, damages or other
+## liability, whether in an action of contract, tort or otherwise, arising from,
+## out of or in connection with the software or the use or other dealings in the
+## software.
 ##
 ## I've made minor changes compared to the original 'nonmaxsuppts' function developed
 ## by Peter Kovesi. The original is available at
@@ -20,9 +29,14 @@
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {[@var{r}, @var{c}] =} immaximas (@var{im}, @var{radius})
 ## @deftypefnx{Function File} {[@var{r}, @var{c}] =} immaximas (@var{im}, @var{radius}, @var{thresh})
-## @deftypefnx{Function File} {[@var{r}, @var{c}, ...] =} immaximas (...)
-## @deftypefnx{Function File} {[..., @var{val}] =} immaximas (...)
-## Finds local spatial maximas of the given image. A local spatial maxima is
+## @deftypefnx{Function File} {[@var{r}, @var{c}, @dots{}] =} immaximas (@dots{})
+## @deftypefnx{Function File} {[@dots{}, @var{val}] =} immaximas (@dots{})
+## Find local spatial maximas.
+##
+## Local spatial maximas should not be mistaken with regional maxima.
+## See @code{imregionalmax} for the later.
+##
+## A local spatial maxima is
 ## defined as an image point with a value that is larger than all neighbouring
 ## values in a square region of width 2*@var{radius}+1. By default @var{radius}
 ## is 1, such that a 3 by 3 neighbourhood is searched. If the @var{thresh} input
@@ -38,7 +52,7 @@
 ## then the last output will contain the image values at the maximas. Currently
 ## this value is not interpolated.
 ##
-## @seealso{ordfilt2, ordfiltn}
+## @seealso{imregionalmax, ordfilt2, ordfiltn}
 ## @end deftypefn
 
 function varargout = immaximas(im, radius, thresh)
@@ -52,8 +66,8 @@ function varargout = immaximas(im, radius, thresh)
   if (nargin <= 2)
     thresh = [];
   endif
-  if (!ismatrix(im))
-    error("immaximas: first input argument must be an array");
+  if (! isnumeric (im))
+    error("immaximas: IM must be a numeric array");
   endif
   if (!isscalar(radius))
     error("immaximas: second input argument must be a scalar or an empty matrix");
@@ -92,7 +106,7 @@ function varargout = immaximas(im, radius, thresh)
       c = im(ind);
       a = (im(indminus1) + im(indplus1))/2 - c;
       b = a + c - im(indminus1);
-      shift = -w*b./(2*a); # Maxima of quadradic 
+      shift = -w*b./(2*a); # Maxima of quadratic 
       
       ## Move point   
       sub{d} += shift;
@@ -105,4 +119,3 @@ function varargout = immaximas(im, radius, thresh)
     varargout{nd+1} = im(ind);
   endif
 endfunction
-
