@@ -14,12 +14,13 @@
 // along with this program; if not, see
 // <http://www.gnu.org/licenses/>.
 
+#include "connectivity.h"
+
 #include <string>
 #include <vector>
 #include <typeinfo>
 
 #include <octave/oct.h>
-#include "connectivity.h"
 
 using namespace octave::image;
 
@@ -320,7 +321,8 @@ connectivity::ndims (const Array<T>& a)
 
 
 Array<octave_idx_type>
-connectivity::padding_lengths (const dim_vector& size, const dim_vector& padded_size)
+connectivity::padding_lengths (const dim_vector& size,
+                               const dim_vector& padded_size)
 {
   const octave_idx_type ndims = size.length ();
   Array<octave_idx_type> lengths (dim_vector (ndims, 1), 0);
@@ -331,3 +333,11 @@ connectivity::padding_lengths (const dim_vector& size, const dim_vector& padded_
   return lengths;
 }
 
+boolNDArray
+connectivity::padding_mask (const dim_vector& size,
+                            const dim_vector& padded_size)
+{
+  boolNDArray mask (padded_size, false);
+  set_padding (size, padded_size, mask, true);
+  return mask;
+}
